Examples
========

.. toctree::
   :maxdepth: 2

   bulk_data
   enriched_citations
   oa_actions
   oa_citations
   oa_rejections
   patent_data
   ifw_example
   petition_decisions
   ptab_appeals
   ptab_interferences
   ptab_trials
